@@ -2,7 +2,7 @@ package Sys::Info::Driver::Windows;
 use strict;
 use warnings;
 
-our $VERSION = '0.74_01';
+our $VERSION = '0.74_02';
 
 use base qw( Exporter );
 use Carp qw( croak    );
@@ -120,15 +120,15 @@ Sys::Info::Driver::Windows - Windows driver for Sys::Info
 
 =head1 SYNOPSIS
 
-    use Sys::Info::Driver::Windows::XS qw(:metrics);
+    use Sys::Info::Driver::Windows qw(:metrics);
     if ( GetSystemMetrics(SM_SERVERR2) ) {
         # do something ...
     }
 
 =head1 DESCRIPTION
 
-This document describes version C<0.74_01> of C<Sys::Info::Driver::Windows>
-released on C<24 March 2010>.
+This document describes version C<0.74_02> of C<Sys::Info::Driver::Windows>
+released on C<2 May 2010>.
 
 B<WARNING>: This version of the module is part of a
 developer (beta) release of the distribution and it is
